Wallet Endpoints
================

System Status (System)
----------------------
.. autofunction:: binance.spot.Spot.system_status

All Coins' Information (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.coin_info

Daily Account Snapshot (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.account_snapshot

Disable Fast Withdraw Switch (USER_DATA)
----------------------------------------
.. autofunction:: binance.spot.Spot.disable_fast_withdraw

Enable Fast Withdraw Switch (USER_DATA)
---------------------------------------
.. autofunction:: binance.spot.Spot.enable_fast_withdraw

Withdraw (USER_DATA)
--------------------
.. autofunction:: binance.spot.Spot.withdraw

Deposit History (supporting network) (USER_DATA)
-------------------------------------------------
.. autofunction:: binance.spot.Spot.deposit_history

Withdraw History (supporting network) (USER_DATA)
-------------------------------------------------
.. autofunction:: binance.spot.Spot.withdraw_history

Deposit Address (supporting network) (USER_DATA)
------------------------------------------------
.. autofunction:: binance.spot.Spot.deposit_address

Account Status (USER_DATA)
--------------------------
.. autofunction:: binance.spot.Spot.account_status

Account API Trading Status (USER_DATA)
--------------------------------------
.. autofunction:: binance.spot.Spot.api_trading_status

DustLog (USER_DATA)
-------------------
.. autofunction:: binance.spot.Spot.dust_log

User Universal Transfer
-----------------------
.. autofunction:: binance.spot.Spot.user_universal_transfer

Query User Universal Transfer History
-------------------------------------
.. autofunction:: binance.spot.Spot.user_universal_transfer_history

Dust Transfer (USER_DATA)
-------------------------
.. autofunction:: binance.spot.Spot.transfer_dust

Asset Dividend Record (USER_DATA)
---------------------------------
.. autofunction:: binance.spot.Spot.asset_dividend_record

Asset Detail (USER_DATA)
------------------------
.. autofunction:: binance.spot.Spot.asset_detail

Trade Fee (USER_DATA)
---------------------
.. autofunction:: binance.spot.Spot.trade_fee

Funding Wallet (USER_DATA)
--------------------------
.. autofunction:: binance.spot.Spot.funding_wallet

User Asset (USER_DATA)
----------------------
.. autofunction:: binance.spot.Spot.user_asset

API Key Permission (USER_DATA)
------------------------------
.. autofunction:: binance.spot.Spot.api_key_permissions

Withdraw (for local entities that require travel rule) (USER_DATA)
------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.local_entity_withdraw

Withdraw History (for local entities that require travel rule) (supporting network) (USER_DATA)
-----------------------------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.local_entity_withdraw_history

Submit Deposit Questionnaire (For local entities that require travel rule) (supporting network) (USER_DATA)
-----------------------------------------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.local_entity_submit_deposit_questionnaire

Deposit History (for local entities that required travel rule) (supporting network) (USER_DATA)
-----------------------------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.local_entity_deposit_history

Get Assets That Can Be Converted Into BNB (USER_DATA)
-----------------------------------------------------
.. autofunction:: binance.spot.Spot.bnb_convertible_assets

Get Cloud-Mining payment and refund history (USER_DATA)
-------------------------------------------------------
.. autofunction:: binance.spot.Spot.cloud_mining_trans_history

One click arrival deposit apply (USER_DATA)
-------------------------------------------
.. autofunction:: binance.spot.Spot.one_click_arrival_deposit_apply

Query User Wallet Balance (USER_DATA)
-------------------------------------
.. autofunction:: binance.spot.Spot.balance

Get symbols delist schedule for spot (MARKET_DATA)
--------------------------------------------------
.. autofunction:: binance.spot.Spot.delist_schedule_symbols
